﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace PrintPreview
{
    public partial class DataGridPrinterLayerProperty : Form
    {
        DataGridPrinterLayer dataGridPrinterLayer = null;

        public DataGridPrinterLayerProperty(DataGridPrinterLayer dataGridPrinterLayer)
        {
            InitializeComponent();

            this.dataGridPrinterLayer = dataGridPrinterLayer;
        }


        private void Window_Load(object sender, EventArgs e)
        {
            LoadLayerProperties();
            LoadResize();
            LoadDrag();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SetLayerProperties();
            SetResize();
            SetDrag();
            Close();

            DialogResult = DialogResult.OK;
        }

        private void LoadLayerProperties()
        {
            dv.DataSource = dataGridPrinterLayer.DataTable;

            foreach (DataColumn column in dataGridPrinterLayer.DataTable.Columns)
            {
                cbxColumns.Items.Add(column.ColumnName);
            }

            lbFontSample.Font = Helper .GetFont ( dataGridPrinterLayer.TextFont);
            lbFontSample.ForeColor = Helper.GetColor(((GeoSolidBrush)dataGridPrinterLayer.TextBrush).Color);
        }

        private void SetLayerProperties()
        {
            dataGridPrinterLayer.DataTable = (DataTable)dv.DataSource;

            dataGridPrinterLayer.TextFont = Helper.GetGeoFont(lbFontSample.Font);
            ((GeoSolidBrush)dataGridPrinterLayer.TextBrush).Color = Helper.GetGeoColor(lbFontSample.ForeColor);
        }

        private void LoadResize()
        {
            switch (dataGridPrinterLayer.ResizeMode)
            {
                case PrinterResizeMode.Fixed:
                    rbtnResizeFixed.Checked = true;
                    break;
                case PrinterResizeMode.MaintainAspectRatio:
                    rbtnResizeMaintainRaio.Checked = true;
                    break;
                case PrinterResizeMode.Resizable:
                    rbtnResize.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetResize()
        {
            if (rbtnResize.Checked)
            {
                dataGridPrinterLayer.ResizeMode = PrinterResizeMode.Resizable;
            }
            else if (rbtnResizeFixed.Checked)
            {
                dataGridPrinterLayer.ResizeMode = PrinterResizeMode.Fixed;
            }
            else if (rbtnResizeMaintainRaio.Checked)
            {
                dataGridPrinterLayer.ResizeMode = PrinterResizeMode.MaintainAspectRatio;
            }
        }

        private void LoadDrag()
        {
            switch (dataGridPrinterLayer.DragMode)
            {
                case PrinterDragMode.Fixed:
                    rbtnDragFixed.Checked = true;
                    break;
                case PrinterDragMode.Draggable:
                    rbtnDraggable.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetDrag()
        {
            if (rbtnDragFixed.Checked)
            {
                dataGridPrinterLayer.DragMode = PrinterDragMode.Fixed;
            }
            else if (rbtnDraggable.Checked)
            {
                dataGridPrinterLayer.DragMode = PrinterDragMode.Draggable;
            }
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            DataTable dt = (DataTable)dv.DataSource;
            string columnName = txtColumnName.Text;
            if (dt.Columns.Contains(columnName))
            {
                MessageBox.Show("Duplicate Column Name");
            }
            else
            {
                dt.Columns.Add(columnName);
                txtColumnName.Text = "";
                cbxColumns.Items.Add(columnName);
            }
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            DataTable dt = (DataTable)dv.DataSource;
            string deletingColumnName = cbxColumns.Text;

            if (dt.Columns.Contains(deletingColumnName))
            {
                dt.Columns.Remove(deletingColumnName);
            }
        }

        private void btnChangeFont_Click(object sender, EventArgs e)
        {
            FontDialog fd = new FontDialog();
            fd.ShowColor = true;
            fd.Font = lbFontSample.Font;
            fd.Color = lbFontSample.ForeColor;

            if (fd.ShowDialog() != DialogResult.Cancel)
            {
                lbFontSample.Font = fd.Font;
                lbFontSample.ForeColor = fd.Color;
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            Close();
        }      
    }
}
