﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace PrintPreview
{
    public partial class MapPrinterLayerProperty : Form
    {
        MapPrinterLayer mapPrinterLayer = null;
        bool isEditing = false;

        public MapPrinterLayerProperty(MapPrinterLayer mapPrinterLayer)
        {
            InitializeComponent();

            this.mapPrinterLayer = mapPrinterLayer;
        }

        private void Window_Load(object sender, EventArgs e)
        {
            LoadLayerProperties();
            LoadResize();
            LoadDrag();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SetLayerProperties();
            SetResize();
            SetDrag();
            Close();

            DialogResult = DialogResult.OK;
        }

        private void LoadLayerProperties()
        {
            if (mapPrinterLayer.Layers.Count > 0
                && mapPrinterLayer.Layers[0].GetType() == typeof(ShapeFileFeatureLayer))
            {
                txtPath.Text = ((ShapeFileFeatureLayer)mapPrinterLayer.Layers[0]).ShapePathFileName;
                isEditing = true;
            }

            if (isEditing)
            {
                txtPath.Enabled = false;
                btnBrowse.Enabled = false;
            }
        }

        private void SetLayerProperties()
        {
            ShapeFileFeatureLayer shapeLayer = new ShapeFileFeatureLayer(txtPath.Text);
            shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.SimpleColors.Black, 1));
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital1;
            shapeLayer.Open();

            if (isEditing)
            {
                mapPrinterLayer.Layers.RemoveAt(0);
            }
            else
            {
                mapPrinterLayer.SetPosition(500, 500, 0, 0, PrintingUnit.Point);
                mapPrinterLayer.MapExtent = shapeLayer.GetBoundingBox();
            }
            mapPrinterLayer.Layers.Add(shapeLayer);
        }

        private void LoadResize()
        {
            switch (mapPrinterLayer.ResizeMode)
            {
                case PrinterResizeMode.Fixed:
                    rbtnResizeFixed.Checked = true;
                    break;
                case PrinterResizeMode.MaintainAspectRatio:
                    rbtnResizeMaintainRaio.Checked = true;
                    break;
                case PrinterResizeMode.Resizable:
                    rbtnResize.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetResize()
        {
            if (rbtnResize.Checked)
            {
                mapPrinterLayer.ResizeMode = PrinterResizeMode.Resizable;
            }
            else if (rbtnResizeFixed.Checked)
            {
                mapPrinterLayer.ResizeMode = PrinterResizeMode.Fixed;
            }
            else if (rbtnResizeMaintainRaio.Checked)
            {
                mapPrinterLayer.ResizeMode = PrinterResizeMode.MaintainAspectRatio;
            }
        }

        private void LoadDrag()
        {
            switch (mapPrinterLayer.DragMode)
            {
                case PrinterDragMode.Fixed:
                    rbtnDragFixed.Checked = true;
                    break;
                case PrinterDragMode.Draggable:
                    rbtnDraggable.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetDrag()
        {
            if (rbtnDragFixed.Checked)
            {
                mapPrinterLayer.DragMode = PrinterDragMode.Fixed;
            }
            else if (rbtnDraggable.Checked)
            {
                mapPrinterLayer.DragMode = PrinterDragMode.Draggable;
            }
        }

        private void btnBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Shape files (*.shp)|*.shp";
            ofd.RestoreDirectory = true;

            if (ofd.ShowDialog() == DialogResult.OK)
            {
                txtPath.Text = ofd.FileName;
            }
        }
    }
}
